aboutsummaryrefslogtreecommitdiffhomepage
path: root/tests/DashPathEffectTest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tests/DashPathEffectTest.cpp')
-rw-r--r--tests/DashPathEffectTest.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/DashPathEffectTest.cpp b/tests/DashPathEffectTest.cpp
index 228aee9031..d7c3d1d8d4 100644
--- a/tests/DashPathEffectTest.cpp
+++ b/tests/DashPathEffectTest.cpp
@@ -19,8 +19,8 @@ DEF_TEST(DashPathEffectTest_crbug_348821, r) {
SkScalar phase = SK_ScalarInfinity; // Used to force the bad fInitialDashLength = -1 path.
SkAutoTUnref<SkDashPathEffect> dash(SkDashPathEffect::Create(intervals, count, phase));
- // NULL -> refuses to work with flattening framework.
- REPORTER_ASSERT(r, dash->getFactory() != NULL);
+ // nullptr -> refuses to work with flattening framework.
+ REPORTER_ASSERT(r, dash->getFactory() != nullptr);
SkWriteBuffer buffer;
buffer.writeFlattenable(dash);